Resources
*********

The following references and learning materials explain SDMX *in general*:

- `SDMX page <https://en.wikipedia.org/wiki/SDMX>`_ on Wikipedia, with a simple summary in 6 languages.
- The **SDMX website** includes:

  - `the authoritative standards <https://sdmx.org/?page_id=5008>`_, and
  - `many detailed guidelines <https://sdmx.org/?page_id=4345>`_ for their use.

  In particular, see `Section 2 — Information Model <http://sdmx.org/wp-content/uploads/SDMX_2-1-1_SECTION_2_InformationModel_201108.pdf>`_ (PDF link).

- The GitHub organization of the `SDMX Technical Standards Working Group <https://github.com/sdmx-twg>`_ hosts other standards information, such as:

  - `Section 7 — REST web service <https://github.com/sdmx-twg/sdmx-rest>`_.

- Eurostat `SDMX ‘InfoSpace’ <https://ec.europa.eu/eurostat/web/sdmx-infospace/welcome>`_ contains many guides and tutorials, from beginner to advanced levels.
- European Central Bank `SDMX REST service help pages <https://sdw-wsrest.ecb.europa.eu/help/>`_ give many examples.
- `SDMXSource <http://www.sdmxsource.org>`_ provides reference implementations of SDMX in Java, .NET, and ActionScript.
